@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 """
 Содержит набор общих вспомогательных классов и функций, использующихся во многих модулях библиотеки.
 """
@@ -7,20 +6,31 @@
 import logging
 import time
 from datetime import date, datetime
-from typing import Any, Union, Callable, List, Tuple
+from typing import Any, Callable, List, Tuple, Union
 
 import requests
+from pydantic import ValidationError
 
-from .consts import TYPES_MAP, business_logic, time_type
-from ..exceptions import *
+from polymatica.common.consts import (
+    BASE_LAYER_NAME,
+    TYPES_MAP,
+    business_logic,
+    time_type,
+)
+from polymatica.exceptions import AuthError, PolymaticaException
 
 
-class TypeConverter():
+class TypeConverter:
     """
     Реализация преобразования типов, определённых Полиматикой, к Python-типам.
     """
 
-    def __init__(self, sc: business_logic, default_value: Any = None, convert_empty_values: bool = True):
+    def __init__(
+        self,
+        sc: business_logic,
+        default_value: Any = None,
+        convert_empty_values: bool = True,
+    ):
         """
         Конструктор класса.
         :param sc: экземпляр класса BusinessLogic.
@@ -81,7 +91,7 @@ class TypeConverter():
         :return: (int) исходные данные в формате даты.
         """
         # немного костыльный способ, но пока ничего лучше не придумал; если упадёт где-нибудь - будем разбираться
-        date_format = self.datetime_format.split(' ')[0]
+        date_format = self.datetime_format.split(" ")[0]
         try:
             result = datetime.strptime(value, date_format).date()
         except (ValueError, TypeError):
@@ -96,7 +106,7 @@ class TypeConverter():
         :return: (int) исходные данные в формате времени.
         """
         # немного костыльный способ, но пока ничего лучше не придумал; если упадёт где-нибудь - будем разбираться
-        time_format = self.datetime_format.split(' ')[1]
+        time_format = self.datetime_format.split(" ")[1]
         try:
             result = datetime.strptime(value, time_format).time()
         except (ValueError, TypeError):
@@ -124,12 +134,12 @@ class TypeConverter():
         :return: (list) начальные данные, преобразованные к нужному типу.
         """
         convert_funcs_map = {
-            'integer': self._convert_to_int,
-            'float': self._convert_to_float,
-            'string': self._convert_to_string,
-            'date': self._convert_to_date,
-            'time': self._convert_to_time,
-            'datetime': self._convert_to_datetime
+            "integer": self._convert_to_int,
+            "float": self._convert_to_float,
+            "string": self._convert_to_string,
+            "date": self._convert_to_date,
+            "time": self._convert_to_time,
+            "datetime": self._convert_to_datetime,
         }
 
         # по идее, в нормальной ситуации длина списков должна совпадать (длина списка типов равна количеству колонок, а
@@ -137,12 +147,15 @@ class TypeConverter():
         if len(types) != len(data):
             exception_func = raise_exception(self.sc)
             exception_func(
-                PolymaticaException, 'Length of column list does not match length of data list!', with_traceback=False)
+                PolymaticaException,
+                "Length of column list does not match length of data list!",
+                with_traceback=False,
+            )
 
         # преобразовываем данные
         result = list()
-        not_converted_values = [float('-inf'), float('inf')]
-        empty_string_values = ['(пустой)', '(empty)']
+        not_converted_values = [float("-inf"), float("inf")]
+        empty_string_values = ["(пустой)", "(empty)"]
         for item in tuple(zip(data, types)):
             # значение текущего поля
             item_value = item[0]
@@ -156,7 +169,10 @@ class TypeConverter():
             # строку, состоящую только из пробелов, также считаем пустой
             if self.convert_empty_values:
                 str_item_value = str(item_value)
-                if str_item_value.lower() in empty_string_values or str_item_value.strip() == str():
+                if (
+                    str_item_value.lower() in empty_string_values
+                    or str_item_value.strip() == ""
+                ):
                     result.append(self.default_value)
                     continue
 
@@ -166,92 +182,6 @@ class TypeConverter():
         return result
 
 
-class JSONDecoder():
-    """
-    Изменение кодировки JSON-подобных структур. Используется при парсинге ответа от сервера (для обработки кириллицы).
-    Конвертация происходит из кодировки, указанной в параметре "from_encoding" в кодировку, указанную в "to_encoding".
-    """
-
-    def __init__(self, from_encoding: str = 'latin1', to_encoding: str = 'utf8'):
-        self._from_enc = from_encoding
-        self._to_enc = to_encoding
-        self._ord_list = self._get_ord_list()
-
-    @property
-    def from_enc(self) -> str:
-        return self._from_enc
-
-    @property
-    def to_enc(self) -> str:
-        return self._to_enc
-
-    @property
-    def char_order_list(self) -> list:
-        return self._ord_list
-
-    def _get_ord_list(self) -> list:
-        """
-        Получить числовые представления всех человеко-читаемых символов.
-        """
-        eng_symbols, rus_symbols = 'abcdefghijklmnopqrstuvwxyz', 'абвгдеёжзийклмнопрстуфхцчшщъыьэюя'
-        digits = '0123456789'
-        spec_symbols = ' .,+-*/<>()[]&^%$#@!"№;:=_?|\{\}\'\t\n\r\b\\'
-        common_str = eng_symbols + eng_symbols.upper() + rus_symbols + rus_symbols.upper() + digits + spec_symbols
-        return [ord(char) for char in common_str]
-
-    def _need_to_decode(self, text: str) -> bool:
-        """
-        Определяем, нужно ли конвертировать строку из одной кодировки в другую.
-        """
-        for char in text:
-            if ord(char) not in self.char_order_list:
-                return True
-        return False
-
-    def _latin_to_utf8_decode(self, text: str) -> str:
-        """
-        Непосредственно само преобразование кодировок.
-        """
-        return text.encode(self.from_enc).decode(self.to_enc)
-
-    def _decode_list(self, current_list: list):
-        """
-        Рекурсивная обработка списков.
-        """
-        for index, current_item in enumerate(current_list):
-            if not current_item:
-                continue
-            if isinstance(current_item, str) and self._need_to_decode(current_item):
-                current_list[index] = self._latin_to_utf8_decode(current_item)
-            elif isinstance(current_item, (list, set)):
-                self._decode_list(current_item)
-            elif isinstance(current_item, dict):
-                self._decode_dict(current_item)
-
-    def _decode_dict(self, current_dict: dict):
-        """
-        Рекурсивная обработка словарей.
-        """
-        for key in list(current_dict.keys()):
-            current_item = current_dict[key]
-            if not current_item:
-                continue
-            if isinstance(current_item, str) and self._need_to_decode(current_item):
-                current_dict[key] = self._latin_to_utf8_decode(current_item)
-            elif isinstance(current_item, (list, set)):
-                self._decode_list(current_item)
-            elif isinstance(current_item, dict):
-                self._decode_dict(current_item)
-
-    def decode(self, current_json: Union[dict, list]):
-        if isinstance(current_json, dict):
-            self._decode_dict(current_json)
-        elif isinstance(current_json, list):
-            self._decode_list(current_json)
-        else:
-            raise DecodeError('Wrong JSON! Expected dict/list, JSON: {}'.format(current_json))
-
-
 def timing(func: Callable) -> Callable:
     """
     Используется как декоратор функций класса BusinessLogic для профилирования времени работы.
@@ -265,15 +195,19 @@ def timing(func: Callable) -> Callable:
         """
         self.func_name = func.__name__
         try:
-            logging.info('Exec func "{}"'.format(self.func_name))
+            logging.info(f'Exec func "{self.func_name}"')
             start_time = time.time()
             result = func(self, *args, **kwargs)
             end_time = time.time()
-            self.func_timing = 'func "{}" exec time: {:.2f} sec'.format(self.func_name, (end_time - start_time))
+            self.func_timing = (
+                f'func "{self.func_name}" exec time: {end_time - start_time:.2f} sec'
+            )
             logging.info(self.func_timing)
             return result
         except SystemExit:
-            logging.critical('Func "{}" failure with SystemExit exception!'.format(self.func_name))
+            logging.critical(
+                f'Func "{self.func_name}" failure with SystemExit exception!'
+            )
             raise
 
     return timing_wrap
@@ -286,7 +220,13 @@ def raise_exception(bl_instance: business_logic) -> Callable:
     :param bl_instance: экземпляр класса BusinessLogic.
     """
 
-    def wrap(exception: Exception, message: str, extend_message: str = '', code: int = 0, with_traceback: bool = True):
+    def wrap(
+        exception: Exception,
+        message: str,
+        extend_message: str = "",
+        code: int = 0,
+        with_traceback: bool = True,
+    ):
         """
         Непосредственно функция, генерирующая пользовательские исключения с заданным сообщением.
 
@@ -322,7 +262,7 @@ def raise_exception(bl_instance: business_logic) -> Callable:
     return wrap
 
 
-def log(message: str, level: str = 'info'):
+def log(message: str, level: str = "info"):
     """
     Запись сообщения в логи.
     :param message: сообщение, записываемое в логи.
@@ -330,25 +270,28 @@ def log(message: str, level: str = 'info'):
         По-умолчанию 'info'.
     """
     level = level.lower()
-    if level not in ['debug', 'info', 'warning', 'error', 'critical']:
-        level = 'info'
-    if level == 'debug':
+    if level not in ["debug", "info", "warning", "error", "critical"]:
+        level = "info"
+    if level == "debug":
         logging.debug(message)
-    elif level == 'info':
+    elif level == "info":
         logging.info(message)
-    elif level == 'warning':
+    elif level == "warning":
         logging.warning(message)
-    elif level == 'error':
+    elif level == "error":
         logging.error(message)
-    elif level == 'critical':
+    elif level == "critical":
         logging.critical(message)
 
 
-def request_with_undefined_suffix_url(possible_suffix_urls: List, base_url: str, data: str, timeout: float,
-                                      headers: dict) -> Tuple[requests.Response, str]:
+def request_with_undefined_suffix_url(
+    possible_suffix_urls: List, base_url: str, data: str, timeout: float, headers: dict
+) -> Tuple[requests.Response, str]:
     for i, url_suffix in enumerate(possible_suffix_urls):
-        current_url = '{}{}'.format(base_url, url_suffix)
-        result = requests.post(url=current_url, data=data, timeout=timeout, headers=headers)
+        current_url = f"{base_url}{url_suffix}"
+        result = requests.post(
+            url=current_url, data=data, timeout=timeout, headers=headers
+        )
 
         # проверки и вывод результата
         status_code = result.status_code
@@ -360,11 +303,65 @@ def request_with_undefined_suffix_url(possible_suffix_urls: List, base_url: str,
             if i != len(possible_suffix_urls) - 1:
                 continue
             else:
-                error_msg = 'Could not determine URL-address of Polymatica stand! ' \
-                            'Base URL: {}, Suffixes: {}, Code: {}, Reason: "{}"'.format(
-                    base_url, possible_suffix_urls, status_code, request.reason)
+                error_msg = (
+                    "Could not determine URL-address of Polymatica stand! "
+                    f"Base URL: {base_url}, Suffixes: {possible_suffix_urls}, "
+                    f'Code: {status_code}, Reason: "{result.reason}"'
+                )
                 raise AuthError(error_msg)
         else:
             error_msg = 'Invalid server response (URL: {}, Code: {}, Reason: "{}", Text: {})'.format(
-                current_url, status_code, request.reason, '<empty>' if not request.text else request.text)
+                current_url,
+                status_code,
+                result.reason,
+                "<empty>" if not result.text else result.text,
+            )
             raise AuthError(error_msg)
+
+
+def validate_params(model, raise_exception_func, **kwargs):
+    type_name_map = {
+        "string_type": "str",
+        "type_error.str": "str",
+        "bool_type": "bool",
+        "value_error.strictbool": "bool",
+        "int_type": "int",
+        "type_error.integer": "int",
+        "float_type": "float",
+        "type_error.float": "float",
+        "list_type": "list",
+        "type_error.list": "list",
+        "dict_type": "dict",
+        "type_error.dict": "dict",
+    }
+
+    try:
+        return model(**kwargs)
+    except ValidationError as e:
+        first = e.errors()[0]
+        loc = first["loc"]
+        raw_expected_type = first.get("type", "invalid_type")
+        expected_type = type_name_map.get(raw_expected_type, raw_expected_type)
+        if len(loc) == 2 and isinstance(loc[1], int):
+            field = f'Elements of parameter "{loc[0]}"'
+        else:
+            field = "Parameter '" + ".".join(str(x) for x in loc) + "'"
+
+        msg = f"{field} must be of type {expected_type}!"
+        return raise_exception_func(ValueError, msg, with_traceback=False)
+
+
+def generate_unique_layer_name(layers_names: list) -> str:
+    """
+    Метод для генерации уникального имени слоя. Если в списке слоёв есть слой с именем "",
+    то фронтенд его преобразует в "Слой 1", поэтому этот метод не возвращает "Слой 1", если
+    в списке слоёв есть "".
+    """
+    n = 1
+    normalized_names = {name.strip() for name in layers_names}
+
+    while True:
+        new_name = f"{BASE_LAYER_NAME} {n}"
+        if new_name not in normalized_names and (n != 1 or "" not in normalized_names):
+            return new_name
+        n += 1
