@@ -1,30 +1,115 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 """ Модуль исполнения команд к серверу Полиматики """
 
-import requests
+import ast
 import json
 import logging
-import ast
 from typing import Dict, Union
-from .error_handler import request_asserts
-from .exceptions import PolymaticaException
-from .common import responce, JSONDecoder
 
+import requests
+
+from polymatica.common import responce
+from polymatica.error_handler import request_asserts
+from polymatica.exceptions import PolymaticaException
 
 # Недопустимые управляюещие символы в json (взято из RFC 1345, начиная с символа 0000)
 INVALID_CONTROL_CHARACTERS = [
-    "\u0000", "\u0001", "\u0002", "\u0003", "\u0004", "\u0005", "\u0006", "\u0007", "\u0008",
-    "\u0009", "\u0010", "\u0011", "\u0012", "\u0013", "\u0014", "\u0015", "\u0016", "\u0017",
-    "\u0018", "\u0019", "\u001a", "\u001b", "\u001c", "\u001d", "\u001e", "\u001f", "\u007f",
-    "\u0080", "\u0081", "\u0082", "\u0083", "\u0084", "\u0085", "\u0086", "\u0087", "\u0088",
-    "\u0089", "\u008a", "\u008b", "\u008c", "\u008d", "\u008e", "\u008f", "\u0090", "\u0091",
-    "\u0092", "\u0093", "\u0094", "\u0095", "\u0096", "\u0097", "\u0098", "\u0099", "\u009a",
-    "\u009b", "\u009c", "\u009d", "\u009e", "\u009f", "\ue000", "\ue001", "\ue002", "\ue003",
-    "\ue004", "\ue005", "\ue006", "\ue007", "\ue008", "\ue009", "\ue010", "\ue011", "\ue012",
-    "\ue013", "\ue014", "\ue015", "\ue016", "\ue017", "\ue018", "\ue019", "\ue01a", "\ue01b",
-    "\ue01c", "\ue01d", "\ue01e", "\ue01f", "\ue020", "\ue021", "\ue022", "\ue023", "\ue024",
-    "\ue025", "\ue026", "\ue027", "\ue027", "\u080f", "\ufeff"
+    "\u0000",
+    "\u0001",
+    "\u0002",
+    "\u0003",
+    "\u0004",
+    "\u0005",
+    "\u0006",
+    "\u0007",
+    "\u0008",
+    "\u0009",
+    "\u0010",
+    "\u0011",
+    "\u0012",
+    "\u0013",
+    "\u0014",
+    "\u0015",
+    "\u0016",
+    "\u0017",
+    "\u0018",
+    "\u0019",
+    "\u001a",
+    "\u001b",
+    "\u001c",
+    "\u001d",
+    "\u001e",
+    "\u001f",
+    "\u007f",
+    "\u0080",
+    "\u0081",
+    "\u0082",
+    "\u0083",
+    "\u0084",
+    "\u0085",
+    "\u0086",
+    "\u0087",
+    "\u0088",
+    "\u0089",
+    "\u008a",
+    "\u008b",
+    "\u008c",
+    "\u008d",
+    "\u008e",
+    "\u008f",
+    "\u0090",
+    "\u0091",
+    "\u0092",
+    "\u0093",
+    "\u0094",
+    "\u0095",
+    "\u0096",
+    "\u0097",
+    "\u0098",
+    "\u0099",
+    "\u009a",
+    "\u009b",
+    "\u009c",
+    "\u009d",
+    "\u009e",
+    "\u009f",
+    "\ue000",
+    "\ue001",
+    "\ue002",
+    "\ue003",
+    "\ue004",
+    "\ue005",
+    "\ue006",
+    "\ue007",
+    "\ue008",
+    "\ue009",
+    "\ue010",
+    "\ue011",
+    "\ue012",
+    "\ue013",
+    "\ue014",
+    "\ue015",
+    "\ue016",
+    "\ue017",
+    "\ue018",
+    "\ue019",
+    "\ue01a",
+    "\ue01b",
+    "\ue01c",
+    "\ue01d",
+    "\ue01e",
+    "\ue01f",
+    "\ue020",
+    "\ue021",
+    "\ue022",
+    "\ue023",
+    "\ue024",
+    "\ue025",
+    "\ue026",
+    "\ue027",
+    "\ue027",
+    "\u080f",
+    "\ufeff",
 ]
 
 
@@ -149,10 +234,17 @@ INVALID_CONTROL_CHARACTERS = [
 
 
 class Executor:
-    """ Класс, выполняющий запросы к серверу Полиматики """
+    """Класс, выполняющий запросы к серверу Полиматики"""
 
-    def __init__(self, session_id: str, manager_uuid: str, base_url: str, command_url: str,
-                 timeout: Union[float, int], poly_version: str):
+    def __init__(
+        self,
+        session_id: str,
+        manager_uuid: str,
+        base_url: str,
+        command_url: str,
+        timeout: Union[float, int],
+        poly_version: str,
+    ):
         """
         Инициализация класса Executor.
         :param session_id: идентификатор сессии.
@@ -160,7 +252,7 @@ class Executor:
         :param base_url: базовый (основной) URL стенда Полиматики.
         :param command_url: URL стенда Полиматики, использующийся для исполнения серверных команд.
         :param timeout: тайм-аут выполнения запросов.
-        :param poly_version: базовая (мажорная) версия Полиматики ('5.6', '5.7', ...)
+        :param poly_version: базовая (мажорная) версия Полиматики ('5.7', ...)
         """
         self.session_id = session_id
         self.manager_uuid = manager_uuid
@@ -173,7 +265,7 @@ class Executor:
         """
         Конвертация заданной строки в кодировку utf-8.
         """
-        return pattern.encode('utf-8')
+        return pattern.encode("utf-8")
 
     @staticmethod
     def get_server_codes(base_url: str) -> Dict:
@@ -182,11 +274,13 @@ class Executor:
         :param base_url: (str) базовый URL-адрес стенда Полиматики.
         :return: словарь списков и состояний, расположенный по пути base_url/server-codes.json.
         """
-        r = requests.get('{}server-codes.json'.format(base_url))
-        assert r.status_code == 200, "Response code == {}!".format(r.status_code)
+        r = requests.get(f"{base_url}server-codes.json")
+        assert r.status_code == 200, f"Response code == {r.status_code}!"
         return r.json()
 
-    def execute_request(self, params: Union[Dict, str], method: str = "POST") -> responce:
+    def execute_request(
+        self, params: Union[Dict, str], method: str = "POST"
+    ) -> responce:
         """
         Непосредственно отправка запроса на сервер Полиматики.
         :param params: (Dict) параметры запроса для метода POST
@@ -194,32 +288,43 @@ class Executor:
         :param method: (str) Тип HTTP-метода ("POST"/"GET"/"PUT").
         :return: (Dict) Ответ сервера на заданный запрос.
         """
-        cookies = {'session': self.session_id}
+        cookies = {"session": self.session_id}
 
         if method == "GET":
             return requests.get(url=params, cookies=cookies, timeout=self.timeout)
         elif method == "PUT":
             headers = {
-                'content-type': 'application/octet-stream',
-                'X-Requested-With': 'XMLHttpRequest',
-                'Upload-Position': "0",
-                'Last-Part': "1"
+                "content-type": "application/octet-stream",
+                "X-Requested-With": "XMLHttpRequest",
+                "Upload-Position": "0",
+                "Last-Part": "1",
             }
-            with open(params, 'rb') as file:
+            with open(params, "rb") as file:
                 r = requests.put(
-                    "{}query/upload.php?".format(self.base_url), data=file, cookies=cookies, headers=headers)
+                    f"{self.base_url}query/upload.php?",
+                    data=file,
+                    cookies=cookies,
+                    headers=headers,
+                )
             return r
         else:
             # получаем текущую пару (команда, состояние)
             request_queries = params.get("queries")
             request_queries = next(iter(request_queries))
             request_command = request_queries.get("command")
-            command_state = (request_command.get("plm_type_code"), request_command.get("state"))
+            command_state = (
+                request_command.get("plm_type_code"),
+                request_command.get("state"),
+            )
 
             # для некоторых команд необходимо передавать запрос в виде строки с кодировкой utf-8, т.к. в запросе
             # могут быть русские символы (кириллица)
-            if command_state in ((210, 7), (210, 14), (502, 5), (503, 6), (503, 24), (505, 4)) or \
-                self.version == '5.7' and command_state in ((207, 21)):
+            if (
+                command_state
+                in ((210, 7), (210, 14), (502, 5), (503, 6), (503, 24), (505, 4))
+                or self.version >= "5.7"
+                and command_state in ((207, 21))
+            ):
                 # command: 207 (user_iface), state: 21 (rename_module) [only 5.7]
                 # command: 210 (user_layer), state: 7 (save_layer)
                 # command: 210 (user_layer), state: 14 (rename_layer)
@@ -229,19 +334,39 @@ class Executor:
                 # command: 505 (group), state: 4 (set_name)
                 # к этой группе относятся команды создания/изменения имени
                 params = str(params)
-                params = params.replace("'", "\"")
-                headers = {'Content-Type': 'text/plain; charset=utf-8', 'Accept': 'text/plain'}
+                params = params.replace("'", '"')
+                headers = {
+                    "Content-Type": "text/plain; charset=utf-8",
+                    "Accept": "text/plain",
+                }
                 if command_state == (502, 5):
-                    headers.update({
-                        "Accept": "application/json, text/javascript, */*; q=0.01",
-                        "Accept-Encoding": "gzip, deflate",
-                        "Accept-Language": "ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7",
-                        "X-Requested-With": "XMLHttpRequest"
-                    })
-                r = requests.post(url=self.command_url, headers=headers, data=self._convert_to_utf_8(params))
-            elif command_state in ((207, 13), (208, 12), (208, 14), (502, 11), (503, 4), (504, 2)) or \
-                    self.version == '5.6' and command_state in ((208, 30), (208, 42), (208, 44)) or \
-                    self.version == '5.7' and command_state in ((208, 28), (208, 40), (208, 42)):
+                    headers.update(
+                        {
+                            "Accept": "application/json, text/javascript, */*; q=0.01",
+                            "Accept-Encoding": "gzip, deflate",
+                            "Accept-Language": "ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7",
+                            "X-Requested-With": "XMLHttpRequest",
+                        }
+                    )
+                r = requests.post(
+                    url=self.command_url,
+                    headers=headers,
+                    data=self._convert_to_utf_8(params),
+                )
+            elif (
+                command_state
+                in (
+                    (207, 13),
+                    (208, 12),
+                    (208, 14),
+                    (208, 58),
+                    (502, 11),
+                    (503, 4),
+                    (504, 2),
+                )
+                or self.version >= "5.7"
+                and command_state in ((208, 28), (208, 40), (208, 42))
+            ):
                 # command: 207 (user_iface), state: 13 (save_settings)
                 # command: 208 (user_cube), state: 12 (test_source_connection_request)
                 # command: 208 (user_cube), state: 14 (data_preview_request)
@@ -251,71 +376,96 @@ class Executor:
                 # command: 502 (dimension), state: 11 (create_union)
                 # command: 503 (fact), state: 4 (create_calc)
                 # command: 504 (filter), state: 2 (pattern_change)
-                params, new_param = str(params), str()
-                for elem in params:
-                    if elem == "'":
-                        new_param += "\""
-                        continue
-                    if elem == "\"":
-                        new_param += "'"
-                        continue
-                    new_param += elem
-                new_param = new_param.replace("False", "false").replace("True", "true").replace("None", "null")
+                # TODO разобраться с этим при рефакторинге
+                if command_state in ((208, 14), (208, 58)):
+                    new_param = json.dumps(params, ensure_ascii=False)
+                else:
+                    params, new_param = str(params), ""
+                    for elem in params:
+                        if elem == "'":
+                            new_param += '"'
+                            continue
+                        if elem == '"':
+                            new_param += "'"
+                            continue
+                        new_param += elem
+                    new_param = (
+                        new_param.replace("False", "false")
+                        .replace("True", "true")
+                        .replace("None", "null")
+                    )
 
                 # определяем заголовки
-                if command_state == (208, 14) or \
-                    self.version == '5.6' and command_state in ((208, 42), (208, 44)) or \
-                    self.version == '5.7' and command_state in ((208, 40), (208, 42)):
+                if (
+                    command_state in ((208, 14), (208, 58))
+                    or self.version >= "5.7"
+                    and command_state in ((208, 40), (208, 42))
+                ):
                     headers = {
-                        'Accept': 'application/json, text/javascript, */*; q=0.01',
-                        'Accept-Encoding': 'gzip, deflate',
-                        'Accept-Language': 'ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7',
-                        'X-Requested-With': 'XMLHttpRequest'
+                        "Accept": "application/json, text/javascript, */*; q=0.01",
+                        "Accept-Encoding": "gzip, deflate",
+                        "Accept-Language": "ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7",
+                        "X-Requested-With": "XMLHttpRequest",
                     }
                 else:
-                    headers = {'Content-Type': 'text/plain; charset=utf-8', 'Accept': 'text/plain'}
+                    headers = {
+                        "Content-Type": "text/plain; charset=utf-8",
+                        "Accept": "text/plain",
+                    }
 
                 r = requests.post(
-                    url=self.command_url, headers=headers, data=self._convert_to_utf_8(new_param), timeout=self.timeout)
+                    url=self.command_url,
+                    headers=headers,
+                    data=self._convert_to_utf_8(new_param),
+                    timeout=self.timeout,
+                )
             else:
-                headers = {'Content-Type': 'application/json; charset=utf-8', 'Accept': 'text/plain'}
+                headers = {
+                    "Content-Type": "application/json; charset=utf-8",
+                    "Accept": "text/plain",
+                }
                 r_params = json.dumps(params)
                 r = requests.post(
-                    url=self.command_url, headers=headers, data=self._convert_to_utf_8(r_params), timeout=self.timeout)
+                    url=self.command_url,
+                    headers=headers,
+                    data=self._convert_to_utf_8(r_params),
+                    timeout=self.timeout,
+                )
 
             # парсинг ответа и проверка его корректности
             if not r.ok:
                 msg = 'Invalid server response (URL: {}, Code: {}, Reason: "{}", Text: {})'.format(
-                    self.command_url, r.status_code, r.reason, '<empty>' if not r.text else r.text)
+                    self.command_url,
+                    r.status_code,
+                    r.reason,
+                    "<empty>" if not r.text else r.text,
+                )
                 raise PolymaticaException(msg)
             else:
                 try:
                     response = json.loads(r.text)
                 except ValueError as ex:
-                    logging.exception("Error converting response to JSON: {}".format(ex))
+                    logging.exception(f"Error converting response to JSON: {ex}")
 
                     # избавляемся от управляющих символов, если они есть
                     str_response = r.text
                     for icc in INVALID_CONTROL_CHARACTERS:
                         if icc in str_response:
-                            str_response = str_response.replace(icc, '')
+                            str_response = str_response.replace(icc, "")
                     # str_response = str_response.replace("'", "\"") # нужна ли эта строчка вообще?!
 
                     # попытка снова преобразовать в json, но уже другим способом
-                    json_str = str_response.replace('true', 'True').replace('false', 'False').replace('null', 'None')
+                    json_str = (
+                        str_response.replace("true", "True")
+                        .replace("false", "False")
+                        .replace("null", "None")
+                    )
                     try:
                         response = ast.literal_eval(json_str)
                     except Exception:
-                        raise PolymaticaException('Cannot convert request response to JSON: {}'.format(ex))
-
-            # TODO: было исправлено по баге http://jira.polymatica.ru/browse/ID-5078
-            # TODO: удалить этот костыль и все связанные файлы, когда правки по баге дойдут до всех стендов
-            # с новым десериализатором на сервере (5.7 и выше) могут приходить "кракозябры" - их необходимо исключить
-            if self.version != '5.6':
-                try:
-                    JSONDecoder().decode(response)
-                except Exception as ex:
-                    logging.exception("JSON decode error: {}".format(ex))
+                        raise PolymaticaException(
+                            f"Cannot convert request response to JSON: {ex}"
+                        )
 
             request_asserts(response, r)
             return response
