@@ -1,6 +1,7 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 """
 Модуль работы с графиками.
 """
 from .graph_interface import IGraph
+
+__all__ = ["IGraph"]
