@@ -1,21 +1,32 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 """
 Описание базового класса работы с графиками.
 """
 
 import re
-from typing import Union, Any, Callable
+from typing import Any, Callable, Union
+
 from ..common import business_logic
 
 BusinessLogic = business_logic
 
-class BaseGraph():
+
+class BaseGraph:
     """
     Класс, являющийся общим предком для всех типов графиков. Содержит обобщённые методы работы с графиками.
     """
-    def __init__(self, base_bl: BusinessLogic, settings: str, grid: str, labels: dict, other: dict,
-                common_params: dict, graph_type: str, int_type: int):
+
+    def __init__(
+        self,
+        base_bl: BusinessLogic,
+        settings: str,
+        grid: str,
+        labels: dict,
+        other: dict,
+        common_params: dict,
+        graph_type: str,
+        int_type: int,
+    ):
         # экземпляр класса BusinessLogic
         self._base_bl = base_bl
         # битмап настроек
@@ -34,7 +45,7 @@ class BaseGraph():
         # целочисленный тип графика, определён Полиматикой в server-codes.json (если не задан, то используется -1)
         self._int_type = int_type
         # название графика
-        self._graph_name = other.get('name', False)
+        self._graph_name = other.get("name", False)
 
     @property
     def base_bl(self) -> business_logic:
@@ -74,9 +85,11 @@ class BaseGraph():
 
     @property
     def default_color(self) -> str:
-        return '#00afd7'
+        return "#00afd7"
 
-    def _check_frequency_impl(self, check_func: Callable, axis_values: dict, start: int, end: int, step: int):
+    def _check_frequency_impl(
+        self, check_func: Callable, axis_values: dict, start: int, end: int, step: int
+    ):
         """
         Реализация проверки значения частоты подписей по осям. Если проверка не пройдена - сгенерируется исключение.
         :param check_func: проверяющая функция, которая возвращает True, если проверка не пройдена.
@@ -91,17 +104,29 @@ class BaseGraph():
                 raise ValueError("Axis value must be int or float type!")
             if check_func(axis_value):
                 params = [axis, start, end, step]
-                raise ValueError("Axis {} frequency must be set in interval [{}, {}] with step {}!".format(*params))
+                raise ValueError(
+                    "Axis {} frequency must be set in interval [{}, {}] with step {}!".format(
+                        *params
+                    )
+                )
 
     def _check_division_value(self, value: str):
         """
         Проверка параметра "Цена деления" на возможные значения.
         :param value: (str) значение параметра "Цена деления".
         """
-        possible_values = ("no", "hundreds", "thousands", "millions", "billions", "trillions")
+        possible_values = (
+            "no",
+            "hundreds",
+            "thousands",
+            "millions",
+            "billions",
+            "trillions",
+        )
         if value not in possible_values:
-            raise ValueError('Param "division_value" must have one of values: {}, found: "{}"'.format(
-                str(possible_values)[1:-1], value))
+            raise ValueError(
+                f'Param "division_value" must have one of values: {str(possible_values)[1:-1]}, found: "{value}"'
+            )
 
     def _get_labels_settings_two_axis_type(self, **kwargs) -> dict:
         """
@@ -110,42 +135,27 @@ class BaseGraph():
         [1, "lines"], [2, "cylinders"], [3, "cumulative_cylinders"], [4, "areas"],
         [5, "cumulative_areas"], [8, "circles"], [9, "circles_series"], [11, "pools"], [13, "corridors"].
         :return:
-            Для версии Полиматики 5.6:
-                {
-                    'axisNotesPeriodX': <value>,
-                    'axisNotesPeriodY': <value>,
-                    'axisXShortFormat': <value>
-                }
-            Для версии Полиматики 5.7:
-                {
-                    'axisNotesPeriodTitle': {'axisNotesPeriodX': <value>, 'axisNotesPeriodY': <value>},
-                    'divisionPrice': <value>
-                }
+            {
+                'axisNotesPeriodTitle': {'axisNotesPeriodX': <value>, 'axisNotesPeriodY': <value>},
+                'divisionPrice': <value>
+            }
         """
-        values_dict = {'OX': self.labels.get('OX', 10), 'OY': self.labels.get('OY', 10)}
+        values_dict = {"OX": self.labels.get("OX", 10), "OY": self.labels.get("OY", 10)}
         self.check_frequency_axis_5_30_5(values_dict)
 
         result_labels = dict()
-        if self.base_bl.polymatica_version == '5.6':
-            result_labels.update({
-                "axisNotesPeriodX": values_dict.get('OX'),
-                "axisNotesPeriodY": values_dict.get('OY')
-            })
-            if kwargs.get("add_short_format", True):
-                short_format = self.labels.get('short_format', False)
-                if not self.check_bool(short_format):
-                    raise ValueError('Param "short_format" must be bool type!')
-                result_labels.update({"axisXShortFormat": short_format})
-        elif self.base_bl.polymatica_version == '5.7':
-            division_value = self.labels.get('division_value', 'no')
-            self._check_division_value(division_value)
-            result_labels.update({
+
+        division_value = self.labels.get("division_value", "no")
+        self._check_division_value(division_value)
+        result_labels.update(
+            {
                 "axisNotesPeriodTitle": {
-                    "axisNotesPeriodX": values_dict.get('OX'),
-                    "axisNotesPeriodY": values_dict.get('OY')
+                    "axisNotesPeriodX": values_dict.get("OX"),
+                    "axisNotesPeriodY": values_dict.get("OY"),
                 },
-                "divisionPrice": division_value
-            })
+                "divisionPrice": division_value,
+            }
+        )
 
         return result_labels
 
@@ -162,15 +172,15 @@ class BaseGraph():
         """
         default_axis_value = 2.5
         values_dict = {
-            'OX': self.labels.get('OX', default_axis_value),
-            'OY': self.labels.get('OY', default_axis_value),
-            'OZ': self.labels.get('OZ', default_axis_value)
+            "OX": self.labels.get("OX", default_axis_value),
+            "OY": self.labels.get("OY", default_axis_value),
+            "OZ": self.labels.get("OZ", default_axis_value),
         }
         self.check_frequency_axis_1_10_05(values_dict)
         return {
-            "axisNotesPeriodX": values_dict.get('OX'),
-            "axisNotesPeriodY": values_dict.get('OY'),
-            "axisNotesPeriodZ": values_dict.get('OZ')
+            "axisNotesPeriodX": values_dict.get("OX"),
+            "axisNotesPeriodY": values_dict.get("OY"),
+            "axisNotesPeriodZ": values_dict.get("OZ"),
         }
 
     def get_labels_settings(self, _type: str, **kwargs) -> dict:
@@ -184,9 +194,11 @@ class BaseGraph():
             return self._get_labels_settings_two_axis_type(**kwargs)
         elif _type == "three_axis":
             return self._get_labels_settings_two_three_type(**kwargs)
-        raise NotImplementedError('Type "{}" is not implemented!'.format(_type))
+        raise NotImplementedError(f'Type "{_type}" is not implemented!')
 
-    def check_olap_configuration(self, left_dims_count: int, top_dims_count: int, fact_count: int, marked: bool):
+    def check_olap_configuration(
+        self, left_dims_count: int, top_dims_count: int, fact_count: int, marked: bool
+    ):
         """
         Сверка текущей конфигурации OLAP-модуля на соответствие заданному типу графика.
         :param left_dims_count: минимальное количество левых размерностей, требующихся для построения графика.
@@ -202,10 +214,15 @@ class BaseGraph():
             в любом случае). В этом случае значение параметра должно быть None.
         """
         # olap_config имеет поля: 'top_dim_count', 'left_dim_count', 'fact_count', 'marked'
-        olap_config = self.common_params.get('olap_config')
-        if olap_config.get('left_dim_count') < left_dims_count or olap_config.get('top_dim_count') < top_dims_count or \
-            olap_config.get('fact_count') < fact_count or marked is not None and olap_config.get('marked') != marked:
-            raise ValueError('Graph cannot be draw with current OLAP configuration!')
+        olap_config = self.common_params.get("olap_config")
+        if (
+            olap_config.get("left_dim_count") < left_dims_count
+            or olap_config.get("top_dim_count") < top_dims_count
+            or olap_config.get("fact_count") < fact_count
+            or marked is not None
+            and olap_config.get("marked") != marked
+        ):
+            raise ValueError("Graph cannot be draw with current OLAP configuration!")
 
     def get_actual_settings(self, field_names: list) -> dict:
         """
@@ -217,8 +234,12 @@ class BaseGraph():
         """
         # если передано неверное число настроек - бросаем ошибку
         if len(self.settings) != len(field_names):
-            raise ValueError("Settings length can only equals {} for this graph type!".format(len(field_names)))
-        return {field: bool(int(self.settings[i])) for i, field in enumerate(field_names)}
+            raise ValueError(
+                f"Settings length can only equals {len(field_names)} for this graph type!"
+            )
+        return {
+            field: bool(int(self.settings[i])) for i, field in enumerate(field_names)
+        }
 
     def check_frequency_axis_5_30_5(self, axis_values: dict):
         """
@@ -226,7 +247,9 @@ class BaseGraph():
         Паттерн проверки: значения могут быть от 5 до 30 с шагом 5.
         :param axis_values: данные частоты подписей по осям.
         """
-        self._check_frequency_impl(lambda item: item % 5 != 0 or item < 5 or item > 30, axis_values, 5, 30, 5)
+        self._check_frequency_impl(
+            lambda item: item % 5 != 0 or item < 5 or item > 30, axis_values, 5, 30, 5
+        )
 
     def check_frequency_axis_1_10_05(self, axis_values: dict):
         """
@@ -235,7 +258,12 @@ class BaseGraph():
         :param axis_values: данные частоты подписей по осям.
         """
         self._check_frequency_impl(
-            lambda item: round(item * 10) % 5 != 0 or item < 1 or item > 10, axis_values, 1, 10, 0.5)
+            lambda item: round(item * 10) % 5 != 0 or item < 1 or item > 10,
+            axis_values,
+            1,
+            10,
+            0.5,
+        )
 
     def check_bool(self, value: Any) -> bool:
         """
@@ -265,7 +293,13 @@ class BaseGraph():
         """
         return isinstance(value, list)
 
-    def check_interval_with_step(self, name: str, value: Union[int, float], interval: tuple, step: Union[int, float]):
+    def check_interval_with_step(
+        self,
+        name: str,
+        value: Union[int, float],
+        interval: tuple,
+        step: Union[int, float],
+    ):
         """
         Проверка заданного значения на вхождение в интервал с заданным шагом.
         Ничего не возвращает, но может сгенерировать исключение.
@@ -276,40 +310,57 @@ class BaseGraph():
         """
         # определяем проверяющую функцию, которая возвращает True, если значение не подходит под заданный паттерн
         if interval == (0, 1) and step == 0.01:
-            check_func = lambda item: item * 100 not in range(0, 101) or item < 0 or item > 1
+            check_func = (  # noqa: E731
+                lambda item: item * 100 not in range(0, 101) or item < 0 or item > 1
+            )
         elif interval == (0, 1) and step == 0.05:
-            check_func = lambda item: round(item * 100) % 5 != 0 or item < 0 or item > 1
+            check_func = (  # noqa: E731
+                lambda item: round(item * 100) % 5 != 0 or item < 0 or item > 1
+            )
         elif interval == (1, 20) and step == 0.5:
-            check_func = lambda item: round(item * 10) % 5 != 0 or item < 1 or item > 20
+            check_func = (  # noqa: E731
+                lambda item: round(item * 10) % 5 != 0 or item < 1 or item > 20
+            )
         elif interval == (0.5, 5) and step == 0.1:
-            check_func = lambda item: item * 10 not in range(5, 51) or item < 0.5 or item > 5
+            check_func = (  # noqa: E731
+                lambda item: item * 10 not in range(5, 51) or item < 0.5 or item > 5
+            )
         elif interval == (1, 5) and step == 0.1:
-            check_func = lambda item: item * 10 not in range(10, 51) or item < 1 or item > 5
+            check_func = (  # noqa: E731
+                lambda item: item * 10 not in range(10, 51) or item < 1 or item > 5
+            )
         elif interval == (1, 10) and step == 0.1:
-            check_func = lambda item: item * 10 not in range(10, 101) or item < 1 or item > 10
+            check_func = (  # noqa: E731
+                lambda item: item * 10 not in range(10, 101) or item < 1 or item > 10
+            )
         elif interval == (5, 10) and step == 0.1:
-            check_func = lambda item: item * 10 not in range(50, 101) or item < 5 or item > 10
+            check_func = (  # noqa: E731
+                lambda item: item * 10 not in range(50, 101) or item < 5 or item > 10
+            )
         elif interval == (5, 15) and step == 0.1:
-            check_func = lambda item: item * 10 not in range(50, 151) or item < 5 or item > 15
+            check_func = (  # noqa: E731
+                lambda item: item * 10 not in range(50, 151) or item < 5 or item > 15
+            )
         elif interval == (0, 5) and step == 1:
-            check_func = lambda item: item not in range(0, 6)
+            check_func = lambda item: item not in range(0, 6)  # noqa: E731
         elif interval == (1, 50) and step == 1:
-            check_func = lambda item: item not in range(1, 51)
+            check_func = lambda item: item not in range(1, 51)  # noqa: E731
         elif interval == (0, 100) and step == 1:
-            check_func = lambda item: item not in range(0, 101)
+            check_func = lambda item: item not in range(0, 101)  # noqa: E731
         elif interval == (7, 15) and step == 1:
-            check_func = lambda item: item not in range(7, 16)
+            check_func = lambda item: item not in range(7, 16)  # noqa: E731
         elif interval == (4, 48) and step == 1:
-            check_func = lambda item: item not in range(4, 49)
+            check_func = lambda item: item not in range(4, 49)  # noqa: E731
         else:
             return
         # если проверка пройдена - генерируем ошибку
         if check_func(value):
-            msg = 'Param "{}" must be set in interval [{}, {}] with step {}!'.format(
-                name, interval[0], interval[1], step)
+            msg = f'Param "{name}" must be set in interval [{interval[0]}, {interval[1]}] with step {step}!'
             raise ValueError(msg)
 
-    def check_range_with_step(self, name: str, value: tuple, interval: tuple, step: Union[int, float]):
+    def check_range_with_step(
+        self, name: str, value: tuple, interval: tuple, step: Union[int, float]
+    ):
         """
         Проверка заданного диапазона. Суть проверки:
             1. Нижняя граница диапазона должна быть меньше или равна верхней границе.
@@ -320,26 +371,28 @@ class BaseGraph():
         :param interval: интервал, в который должно входить значение верхней и нижней границы; имеет вид (a, b)
         :param step: шаг значений на интервале (может быть как целочисленным, так и нет)
         """
-        error_msg = str()
+        error_msg = ""
         min_value, max_value = value[0], value[1]
         if max_value < min_value:
-            error_msg = 'top range border should not be less than the bottom range border!'
+            error_msg = (
+                "top range border should not be less than the bottom range border!"
+            )
         try:
             self.check_interval_with_step(name, min_value, interval, step)
             self.check_interval_with_step(name, max_value, interval, step)
         except ValueError:
-            error_msg = 'borders must be set in interval [{}, {}] with step {}!'.format(interval[0], interval[1], step)
+            error_msg = f"borders must be set in interval [{interval[0]}, {interval[1]}] with step {step}!"
         if error_msg:
-            raise ValueError('Wrong param "{}": {}'.format(name, error_msg))
+            raise ValueError(f'Wrong param "{name}": {error_msg}')
 
     def check_color(self, color: str):
         """
         Проверка соответствия цвета шаблону "#rrggbb".
         Ничего не возвращает, но может сгенерировать исключение вследствие провалившейся проверки.
         """
-        color_reg = re.compile(r'^#[0-9a-fA-F]{6}$')
+        color_reg = re.compile(r"^#[0-9a-fA-F]{6}$")
         if not color_reg.match(color):
-            raise ValueError('Wrong color: "{}"! Color pattern: "#RRGGBB"!'.format(color))
+            raise ValueError(f'Wrong color: "{color}"! Color pattern: "#RRGGBB"!')
 
     def save_graph_settings(self, graph_config: dict):
         """
@@ -348,8 +401,8 @@ class BaseGraph():
         self.base_bl.execute_manager_command(
             command_name="user_iface",
             state="save_settings",
-            module_id=self.common_params.get('graph_module_id'),
-            settings=graph_config
+            module_id=self.common_params.get("graph_module_id"),
+            settings=graph_config,
         )
 
     def get_graph_config(self) -> dict:
@@ -357,37 +410,33 @@ class BaseGraph():
         Возвращает основную часть настроек графика (то есть ту часть, которая не параметризуется пользователем).
         :return: Основная часть конфигурации графика.
         """
-        module_size = self.common_params.get('module_size')
+        module_size = self.common_params.get("module_size")
         graph_settings = {
             # строковый идентификатор графика
             "plotName": self.graph_type,
             # размеры окна
-            "geometry": {"width": module_size.get('width'), "height": module_size.get('height')},
+            "geometry": {
+                "width": module_size.get("width"),
+                "height": module_size.get("height"),
+            },
             # конфигурация графика
             "plotData": {
                 self.graph_type: {
                     # для каждого типа графика тут будет прописан конфиг,
                     # сформированный на основе пользовательских настроек
-                    "config": {
-                    },
+                    "config": {},
                     # в этом блоке описываем состояние графика
                     "state": {
                         # цвета, используемые при построении
-                        "colors": {
-                        },
+                        "colors": {},
                         # название графика
                         "title": self.graph_name,
                         # масштабирование
-                        "zoom": {
-                            "k": 1,
-                            "x": 0,
-                            "y": 0,
-                            "z": 0
-                        }
+                        "zoom": {"k": 1, "x": 0, "y": 0, "z": 0},
                     },
                     # для некоторых типов графиков указывается информация об отображаемом множестве верхних размерностей
-                    "query": {}
+                    "query": {},
                 }
-            }
+            },
         }
         return graph_settings
